==> ugene_1.3.3%2Brepack.orig.tar.gz: ugene-1.3.3/src/core/src/document_format/DocumentFormatUtils.h <==
/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _GB2_DOCUMENT_FORMAT_UTILS_H_
#define _GB2_DOCUMENT_FORMAT_UTILS_H_

#include <core_api/LRegion.h>

#include <QtCore/QStringList>

//todo: move to separate header
#define MERGE_MULTI_DOC_GAP_SIZE_SETTINGS           "merge_gap"
#define MERGE_MULTI_DOC_SEQUENCE_SIZE_SETTINGS      "merge_size"

namespace GB2  {

class Document;
class DocumentFormat;
class DNAAlphabet;
class DNASequenceObject;
class GObject;
class MAlignment;

class GB2_COREAPI_EXPORT DocumentFormatUtils {
public:
    static DNASequenceObject* addSequenceObject(QList<GObject*>& objects, const QString& sequenceName, QByteArray& sequence, DNAAlphabet* al = NULL);

    /** if no docURL provided -> relations are not set*/
    static DNASequenceObject* addMergedSequenceObject(QList<GObject*>& objects, const QString& docUrl, const QStringList& contigs, 
                            QByteArray& mergedSequence, const QList<LRegion>& mergedMapping);

    static DNAAlphabet* findAlphabet(const QByteArray& arr);
    
    static QList<DNAAlphabet*> findAlphabets(const QByteArray& arr);

    static DNAAlphabet* findAlphabet(const QByteArray& arr, const QList<LRegion>& regionsToProcess);

    static void trySqueeze(QByteArray& a);

    static int getIntSettings(const QVariantMap& fs, const char* sName, int defVal);

    static void updateFormatSettings(QList<GObject*>& objects, QVariantMap& fs);

    static void addOffset(QList<LRegion>& location, int offset);

    // the best match goes first in the returned list
    static QList<DocumentFormat*> detectFormat(const QString& url);

    static void assignAlphabet(MAlignment& ma);

};

}//namespace
 
#endif

==> ugene_1.7.1%2Brepack.orig.tar.gz: ugene-1.7.1/src/core/src/document_format/DocumentFormatUtils.h <==
/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _GB2_DOCUMENT_FORMAT_UTILS_H_
#define _GB2_DOCUMENT_FORMAT_UTILS_H_

#include <core_api/LRegion.h>

#include <QtCore/QStringList>

#include <core_api/IOAdapter.h>

//todo: move to separate header
#define MERGE_MULTI_DOC_GAP_SIZE_SETTINGS           "merge_gap"
#define MERGE_MULTI_DOC_SEQUENCE_SIZE_SETTINGS      "merge_size"

namespace GB2  {

class Document;
class DocumentFormat;
class DNAAlphabet;
class DNASequenceObject;
class GObject;
class MAlignment;
class DNASequence;

class GB2_COREAPI_EXPORT DocumentFormatUtils {
public:
    static DNASequenceObject* addSequenceObject(QList<GObject*>& objects, const QString& name, DNASequence& seq);

    /** if no docURL provided -> relations are not set*/
    static DNASequenceObject* addMergedSequenceObject(QList<GObject*>& objects, const GUrl& docUrl, const QStringList& contigs, 
                            QByteArray& mergedSequence, const QList<LRegion>& mergedMapping);

    static DNAAlphabet* findAlphabet(const QByteArray& arr);
    
    static QList<DNAAlphabet*> findAlphabets(const QByteArray& arr);

    static DNAAlphabet* findAlphabet(const QByteArray& arr, const QList<LRegion>& regionsToProcess);

    static void trySqueeze(QByteArray& a);

    static int getIntSettings(const QVariantMap& fs, const char* sName, int defVal);

    static void updateFormatSettings(QList<GObject*>& objects, QVariantMap& fs);

    static void addOffset(QList<LRegion>& location, int offset);

    // the best match goes first in the returned list
    static QList<DocumentFormat*> detectFormat(const GUrl& url);
    
    // io - opened io adapter
    static QList<DocumentFormat*> detectFormat( IOAdapter* io );
    static void assignAlphabet(MAlignment& ma);

};

}//namespace

#endif
